intelmq.bots.collectors.misp package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.misp package

## Submodules

## intelmq.bots.collectors.misp.collector module

A collector for grabbing appropriately tagged events from MISP.

param - misp_url

  URL of the MISP server

param - misp_key

  API key for accessing MISP

param - misp_tag_to_process

  MISP tag identifying events to be processed

param - misp_tag_processed

  MISP tag identifying events that have been processed

PyMISP versions released after January 2020 will no longer support the “old” PyMISP class. For compatibility:

> - older versions of pymisp still work with this bot

> - the deprecated parameter misp_verify will create a DeprecationWarning

`intelmq.bots.collectors.misp.collector.` `BOT`

  alias of `intelmq.bots.collectors.misp.collector.MISPCollectorBot`

class `intelmq.bots.collectors.misp.collector.` `MISPCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `init`()
  `process`()

## Module contents